pub struct G2Prepared<P: MNT4Config> {
pub x: Fp2<P::Fp2Config>,
pub y: Fp2<P::Fp2Config>,
pub x_over_twist: Fp2<P::Fp2Config>,
pub y_over_twist: Fp2<P::Fp2Config>,
pub double_coefficients: Vec<AteDoubleCoefficients<P>>,
pub addition_coefficients: Vec<AteAdditionCoefficients<P>>,
}Fields
x: Fp2<P::Fp2Config>y: Fp2<P::Fp2Config>x_over_twist: Fp2<P::Fp2Config>y_over_twist: Fp2<P::Fp2Config>double_coefficients: Vec<AteDoubleCoefficients<P>>addition_coefficients: Vec<AteAdditionCoefficients<P>>Trait Implementations
Sourceimpl<P: MNT4Config> CanonicalDeserialize for G2Prepared<P>
impl<P: MNT4Config> CanonicalDeserialize for G2Prepared<P>
Sourcefn deserialize_with_mode<R: Read>(
reader: R,
compress: Compress,
validate: Validate,
) -> Result<Self, SerializationError>
fn deserialize_with_mode<R: Read>( reader: R, compress: Compress, validate: Validate, ) -> Result<Self, SerializationError>
The general deserialize method that takes in customization flags.
Sourcefn deserialize_compressed<R>(reader: R) -> Result<Self, SerializationError>where
R: Read,
fn deserialize_compressed<R>(reader: R) -> Result<Self, SerializationError>where
R: Read,
Reads
Self from reader using the compressed form if applicable.
Performs validation if applicable.Sourcefn deserialize_compressed_unchecked<R>(
reader: R,
) -> Result<Self, SerializationError>where
R: Read,
fn deserialize_compressed_unchecked<R>(
reader: R,
) -> Result<Self, SerializationError>where
R: Read,
Reads
Self from reader using the compressed form if applicable, without validating the
deserialized value. Read moreSourcefn deserialize_uncompressed<R>(reader: R) -> Result<Self, SerializationError>where
R: Read,
fn deserialize_uncompressed<R>(reader: R) -> Result<Self, SerializationError>where
R: Read,
Reads
Self from reader using the uncompressed form. Performs validation if applicable.Sourcefn deserialize_uncompressed_unchecked<R>(
reader: R,
) -> Result<Self, SerializationError>where
R: Read,
fn deserialize_uncompressed_unchecked<R>(
reader: R,
) -> Result<Self, SerializationError>where
R: Read,
Reads
Self from reader using the uncompressed form, without validating the deserialized
value. Read moreSourceimpl<P: MNT4Config> CanonicalSerialize for G2Prepared<P>
impl<P: MNT4Config> CanonicalSerialize for G2Prepared<P>
Sourcefn serialize_with_mode<W: Write>(
&self,
writer: W,
compress: Compress,
) -> Result<(), SerializationError>
fn serialize_with_mode<W: Write>( &self, writer: W, compress: Compress, ) -> Result<(), SerializationError>
The general serialize method that takes in customization flags.
Sourcefn serialized_size(&self, compress: Compress) -> usize
fn serialized_size(&self, compress: Compress) -> usize
Returns the size in bytes of the serialized version of
self with the given compression mode.Sourcefn serialize_compressed<W>(&self, writer: W) -> Result<(), SerializationError>where
W: Write,
fn serialize_compressed<W>(&self, writer: W) -> Result<(), SerializationError>where
W: Write,
Serializes
self into writer using the compressed form if applicable.Sourcefn compressed_size(&self) -> usize
fn compressed_size(&self) -> usize
Returns the size in bytes of the compressed serialized version of
self.Sourcefn serialize_uncompressed<W>(&self, writer: W) -> Result<(), SerializationError>where
W: Write,
fn serialize_uncompressed<W>(&self, writer: W) -> Result<(), SerializationError>where
W: Write,
Serializes
self into writer using the uncompressed form.Sourcefn uncompressed_size(&self) -> usize
fn uncompressed_size(&self) -> usize
Returns the size in bytes of the uncompressed serialized version of
self.Sourceimpl<P: MNT4Config> Clone for G2Prepared<P>where
Fp2<P::Fp2Config>: Clone,
Vec<AteDoubleCoefficients<P>>: Clone,
Vec<AteAdditionCoefficients<P>>: Clone,
impl<P: MNT4Config> Clone for G2Prepared<P>where
Fp2<P::Fp2Config>: Clone,
Vec<AteDoubleCoefficients<P>>: Clone,
Vec<AteAdditionCoefficients<P>>: Clone,
Sourceimpl<P: MNT4Config> Debug for G2Prepared<P>where
Fp2<P::Fp2Config>: Debug,
Vec<AteDoubleCoefficients<P>>: Debug,
Vec<AteAdditionCoefficients<P>>: Debug,
impl<P: MNT4Config> Debug for G2Prepared<P>where
Fp2<P::Fp2Config>: Debug,
Vec<AteDoubleCoefficients<P>>: Debug,
Vec<AteAdditionCoefficients<P>>: Debug,
Sourceimpl<P: MNT4Config> Default for G2Prepared<P>
impl<P: MNT4Config> Default for G2Prepared<P>
Sourceimpl<'a, P: MNT4Config> From<&'a Affine<<P as MNT4Config>::G2Config>> for G2Prepared<P>
impl<'a, P: MNT4Config> From<&'a Affine<<P as MNT4Config>::G2Config>> for G2Prepared<P>
Sourceimpl<'a, P: MNT4Config> From<&'a Projective<<P as MNT4Config>::G2Config>> for G2Prepared<P>
impl<'a, P: MNT4Config> From<&'a Projective<<P as MNT4Config>::G2Config>> for G2Prepared<P>
Sourcefn from(g2: &'a G2Projective<P>) -> Self
fn from(g2: &'a G2Projective<P>) -> Self
Converts to this type from the input type.
Sourceimpl<P: MNT4Config> From<Affine<<P as MNT4Config>::G2Config>> for G2Prepared<P>
impl<P: MNT4Config> From<Affine<<P as MNT4Config>::G2Config>> for G2Prepared<P>
Sourceimpl<P: MNT4Config> From<Projective<<P as MNT4Config>::G2Config>> for G2Prepared<P>
impl<P: MNT4Config> From<Projective<<P as MNT4Config>::G2Config>> for G2Prepared<P>
Sourcefn from(g2: G2Projective<P>) -> Self
fn from(g2: G2Projective<P>) -> Self
Converts to this type from the input type.
Sourceimpl<P: MNT4Config> PartialEq for G2Prepared<P>where
Fp2<P::Fp2Config>: PartialEq,
Vec<AteDoubleCoefficients<P>>: PartialEq,
Vec<AteAdditionCoefficients<P>>: PartialEq,
impl<P: MNT4Config> PartialEq for G2Prepared<P>where
Fp2<P::Fp2Config>: PartialEq,
Vec<AteDoubleCoefficients<P>>: PartialEq,
Vec<AteAdditionCoefficients<P>>: PartialEq,
Sourceimpl<P: MNT4Config> Valid for G2Prepared<P>
impl<P: MNT4Config> Valid for G2Prepared<P>
Sourceconst TRIVIAL_CHECK: bool
const TRIVIAL_CHECK: bool
Whether the
check method is trivial (i.e. always returns Ok(())). If this is true,
the batch_check method will skip all checks and return Ok(()).
This should be set to true for types where check is trivial, e.g.
integers, field elements, etc.
This is false by default.
This is primarily an optimization to skip unnecessary checks in batch_check.Sourcefn check(&self) -> Result<(), SerializationError>
fn check(&self) -> Result<(), SerializationError>
Checks whether
self is valid. If self is valid, returns Ok(()). Otherwise, returns
an error describing the failure.
This method is called by deserialize_with_mode if validate is Validate::Yes.Sourcefn batch_check<'a>(
batch: impl Iterator<Item = &'a Self> + Send,
) -> Result<(), SerializationError>where
Self: 'a,
fn batch_check<'a>(
batch: impl Iterator<Item = &'a Self> + Send,
) -> Result<(), SerializationError>where
Self: 'a,
Checks whether all items in
batch are valid. If all items are valid, returns Ok(()).
Otherwise, returns an error describing the first failure.impl<P: MNT4Config> Eq for G2Prepared<P>where
Fp2<P::Fp2Config>: PartialEq,
Vec<AteDoubleCoefficients<P>>: PartialEq,
Vec<AteAdditionCoefficients<P>>: PartialEq,